pub(crate) fn main()Expand description
Main entry point for mobile builds, which is required by Tauri but delegates to the primary binary logic in the Binary module.
pub(crate) fn main()Main entry point for mobile builds, which is required by Tauri but delegates to the primary binary logic in the Binary module.